@@ -9,9 +9,9 @@ import MySQLdb
 import MySQLdb.cursors
 # mine
 from HandwrittenData import HandwrittenData
-import utils
-import preprocessing
-import features
+import hwrt.utils as utils
+import hwrt.preprocessing as preprocessing
+import hwrt.features as features
 
 
 def fetch_data(raw_data_id):
